Module inline

Module inline 

Inline-level analysis utilities.

Extracts positioned references from text content by walking the AST’s InlineNode tree and raw source text in parallel to compute correct byte positions.

Structs

PositionedReference
A reference found in inline text, with its source position and classified type.

Functions

extract_references
Extract all references from a text node with their source positions.