Module utils

Module utils 

Functions

collect_all_annotations
Collects all annotations in the document into a vector.
collect_footnote_definitions
Collects all footnote definitions from a document.
find_annotation_at_position
find_definition_at_position
find_definition_by_subject
find_definitions_by_subject
find_notes_session
Finds the Notes/Footnotes session in a document.
find_session_at_position
find_sessions_by_identifier
for_each_annotation
Visits every annotation in the document, invoking the callback for each.
for_each_text_content
Visits every text content node in the document, invoking the callback for each.
reference_span_at_position
session_identifier