Functions
- collect_
all_ annotations - Collects all annotations in the document into a vector.
- collect_
footnote_ definitions - Collects all footnote definitions from a document.
- find_
annotation_ at_ position - find_
definition_ at_ position - find_
definition_ by_ subject - find_
definitions_ by_ subject - find_
notes_ session - Finds the Notes/Footnotes session in a document.
- find_
session_ at_ position - find_
sessions_ by_ identifier - for_
each_ annotation - Visits every annotation in the document, invoking the callback for each.
- for_
each_ text_ content - Visits every text content node in the document, invoking the callback for each.
- reference_
span_ at_ position - session_
identifier