Module utils

Module utils 

Functions

collect_all_annotations
Collects all annotations in the document into a vector.
find_annotation_at_position
find_definition_at_position
find_definition_by_subject
find_definitions_by_subject
find_session_at_position
find_sessions_by_identifier
for_each_annotation
Visits every annotation in the document, invoking the callback for each.
for_each_text_content
Visits every text content node in the document, invoking the callback for each.
reference_span_at_position
session_identifier